@@ -1,12 +1,12 @@
 #!/usr/bin/perl -w
 use strict;
 use utf8;
-use lib qw(lib);     
+use lib qw(%PATH%lib);     
 use MySQL::Admin::Translate;
 use vars qw($m_hrLang );
 use CGI qw(param header);
 *m_hrLang = \$MySQL::Admin::Translate::lang;
-loadTranslate('%CONFIG%/translate.pl');
+loadTranslate('%PATH%config/translate.pl');
 my $content = "Lang =function (){\n";
 foreach my $lng (keys %{$m_hrLang}){
     foreach my $key (keys %{$m_hrLang->{$lng}}){
@@ -15,5 +15,5 @@ foreach my $lng (keys %{$m_hrLang}){
     }
 }
 $content .= "}\n";
-print header(-type => 'application/javascript',-charset => 'UTF-8');
+print header(-type => 'application/javascript',-charset => 'UTF-8',-access_control_allow_origin => '*');
 print $content;
